from __future__ import unicode_literals
from django.http import HttpResponse
from django.contrib.auth.decorators import login_required
from django.template import loader
from django.shortcuts import render
from django.conf import settings
import logging
import requests

logger = logging.getLogger('views')

# Create your views here.
# @login_required
def index(request):
    logger.info('Checking user auth to decide on viz access')
    context = {
        'arcadia_server': settings.ARCADIA_SERVER
    }
    if request.user.is_authenticated:
        logger.info('User authenticated: {}'.format(request.user.username))
        post_data = {
            'username': request.user.username,
            'trustedusername': settings.ARCADIA_TRUSTED_USERNAME,
            'trustedpassword': settings.ARCADIA_TRUSTED_PASSWORD
        }
        response = requests.post('{}/arc/trustedauth/getticket'.format(settings.ARCADIA_SERVER), data=post_data, verify=False)
        if response.status_code != 200:
            logger.warn('Error getting Arcadia Ticket: HTTP {} - {}'.format(response.status_code, response.content))
        else:
            ticket = response.content.strip()
            logger.debug('Got Arcadia Ticket: {}'.format(ticket))
            context.update({
                'ticket': ticket
            })
    return render(request, 'arc_embed/index.html', context)

def public(request):
    context = {
        'arcadia_server': settings.ARCADIA_SERVER
    }
    if 'arcadia-reg' in request.COOKIES:
        username = request.COOKIES.get('arcadia-reg')
        logger.info('Show public viz for arcadia-registered user {}'.format(username))
        post_data = {
            'username': 'arc_embed', #use a static user name here
            'trustedusername': settings.ARCADIA_TRUSTED_USERNAME,
            'trustedpassword': settings.ARCADIA_TRUSTED_PASSWORD
        }
        response = requests.post('{}/arc/trustedauth/getticket'.format(settings.ARCADIA_SERVER), data=post_data, verify=False)
        if response.status_code != 200:
            logger.warn('Error getting Arcadia Ticket: HTTP {} - {}'.format(response.status_code, response.content))
        else:
            ticket = response.content.strip()
            logger.debug('Got Arcadia Ticket: {}'.format(ticket))
            context.update({
                'ticket': ticket
            })
    return render(request, 'arc_embed/public.html', context)